@@ -9,15 +9,28 @@
 
 #include <errno.h>
 #include <fcntl.h>
-#include <netinet/in.h>
-#include <netinet/ip.h>
-#include <sys/socket.h>
 #include <sys/types.h>
 #include <unistd.h>
 
-#include "sylogger.h"
+#ifdef WIN32
+#include <Winsock2.h>
+#include <Ws2tcpip.h>
+#include <mswsock.h>
+#else
+#include <netinet/in.h>
+#include <netinet/ip.h>
+#include <sys/socket.h>
+#endif  // WIN32
+
+#include "sysyslog.h"
 #include "symcastsocket.h"
 
+#ifdef WIN32
+#define SYMCASTSOCKET_BIND_MODE QUdpSocket::ReuseAddressHint
+#else
+#define SYMCASTSOCKET_BIND_MODE QUdpSocket::ShareAddress
+#endif  // WIN32
+
 SyMcastSocket::SyMcastSocket(Mode mode,QObject *parent)
   : QObject(parent)
 {
@@ -54,15 +67,16 @@ SyMcastSocket::Mode SyMcastSocket::mode() const
 bool SyMcastSocket::bind(const QHostAddress &addr,uint16_t port)
 {
   if(mcast_recv_socket!=NULL) {
-    if(!mcast_recv_socket->bind(port,QUdpSocket::ShareAddress)) {
+    if(!mcast_recv_socket->bind(addr,port,SYMCASTSOCKET_BIND_MODE)) {
       SySyslog(LOG_ERR,QString().
 	       sprintf("unable to bind port %u for reading [%s]",
 		       port,strerror(errno)));
       exit(256);
     }    
   }
+
   if(mcast_send_socket!=NULL) {
-    if(!mcast_send_socket->bind(addr,port,QUdpSocket::ShareAddress)) {
+    if(!mcast_send_socket->bind(addr,port,SYMCASTSOCKET_BIND_MODE)) {
       SySyslog(LOG_ERR,QString().
 	       sprintf("unable to bind port %u for writing [%s]",
 		       port,strerror(errno)));
@@ -82,7 +96,7 @@ bool SyMcastSocket::bind(uint16_t port)
     exit(256);
   }
   if(mcast_recv_socket!=NULL) {
-    if(!mcast_recv_socket->bind(port,QUdpSocket::ShareAddress)) {
+    if(!mcast_recv_socket->bind(port,SYMCASTSOCKET_BIND_MODE)) {
       SySyslog(LOG_ERR,QString().
 	       sprintf("unable to bind port %u for reading [%s]",
 		       port,strerror(errno)));
@@ -128,28 +142,44 @@ qint64 SyMcastSocket::writeDatagram(const QByteArray &datagram,
 
 void SyMcastSocket::subscribe(const QHostAddress &addr)
 {
-  struct ip_mreqn mreq;
-
   if(mcast_recv_socket==NULL) {
     SySyslog(LOG_ERR,"cannot subscribe on a write-only socket");
     exit(256);
   }
+
+#ifdef WIN32
+  struct ip_mreq_source imr;
+
+  memset(&imr,0,sizeof(imr));
+  imr.imr_multiaddr.s_addr=htonl(addr.toIPv4Address());
+  imr.imr_interface.s_addr=htonl(mcast_iface_address.toIPv4Address());
+  if(setsockopt(mcast_recv_socket->socketDescriptor(),IPPROTO_IP,
+		IP_ADD_MEMBERSHIP,(char *)&imr,sizeof(imr))<0) {
+    SySyslog(LOG_ERR,QString().
+	     sprintf("unable to subscribe to group %s [%s]",
+		     (const char *)addr.toString().toAscii(),strerror(errno)));
+    exit(256);
+  }
+#else
+  struct ip_mreqn mreq;
+
   memset(&mreq,0,sizeof(mreq));
   mreq.imr_multiaddr.s_addr=htonl(addr.toIPv4Address());
   mreq.imr_address.s_addr=htonl(mcast_iface_address.toIPv4Address());
   mreq.imr_ifindex=0;
 #ifdef OSX
   if(setsockopt(mcast_recv_socket->socketDescriptor(),IPPROTO_IP,
-		IP_ADD_MEMBERSHIP,&mreq,sizeof(mreq))<0) {
+    IP_ADD_MEMBERSHIP,&mreq,sizeof(mreq))<0) {
 #else
-    if(setsockopt(mcast_recv_socket->socketDescriptor(),SOL_IP,
-		  IP_ADD_MEMBERSHIP,&mreq,sizeof(mreq))<0) {
+  if(setsockopt(mcast_recv_socket->socketDescriptor(),SOL_IP,
+    IP_ADD_MEMBERSHIP,&mreq,sizeof(mreq))<0) {
 #endif  // OSX
-      SySyslog(LOG_ERR,QString().
-	       sprintf("unable to subscribe to group %s [%s]",
-		      (const char *)addr.toString().toAscii(),strerror(errno)));
+    SySyslog(LOG_ERR,QString().
+      sprintf("unable to subscribe to group %s [%s]",
+        (const char *)addr.toString().toAscii(),strerror(errno)));
     exit(256);
   }
+#endif // WIN32
 }
 
 
@@ -161,12 +191,27 @@ void SyMcastSocket::subscribe(const QString &addr)
 
 void SyMcastSocket::unsubscribe(const QHostAddress &addr)
 {
-  struct ip_mreqn mreq;
-
   if(mcast_recv_socket==NULL) {
     SySyslog(LOG_ERR,"cannot unsubscribe on a write-only socket");
     exit(256);
   }
+
+#ifdef WIN32
+  struct ip_mreq_source imr;
+
+  memset(&imr,0,sizeof(imr));
+  imr.imr_multiaddr.s_addr=htonl(addr.toIPv4Address());
+  imr.imr_interface.s_addr=htonl(mcast_iface_address.toIPv4Address());
+  if(setsockopt(mcast_recv_socket->socketDescriptor(),IPPROTO_IP,
+		IP_DROP_MEMBERSHIP,(char *)&imr,sizeof(imr))<0) {
+    SySyslog(LOG_ERR,QString().
+	     sprintf("unable to subscribe to group %s [%s]",
+		     (const char *)addr.toString().toAscii(),strerror(errno)));
+    exit(256);
+  }
+#else
+  struct ip_mreqn mreq;
+
   memset(&mreq,0,sizeof(mreq));
   mreq.imr_multiaddr.s_addr=htonl(addr.toIPv4Address());
   mreq.imr_address.s_addr=htonl(mcast_iface_address.toIPv4Address());
@@ -183,6 +228,7 @@ void SyMcastSocket::unsubscribe(const QHostAddress &addr)
 		      (const char *)addr.toString().toAscii(),strerror(errno)));
     exit(256);
   }
+#endif  // WIN32
 }
 
 
