@@ -66,7 +66,7 @@ SyRouting::SyRouting(unsigned d_slots,unsigned s_slots,unsigned gpis,unsigned gp
     sy_gpo_states.push_back(0);
   }
 
-  if((d_slots>=SWITCHYARD_MAX_SLOTS)||(s_slots>=SWITCHYARD_MAX_SLOTS)) {
+  if((d_slots>SWITCHYARD_MAX_SLOTS)||(s_slots>SWITCHYARD_MAX_SLOTS)) {
     SySyslog(LOG_ERR,"maximum slot count exceeded");
     exit(256);
   }
@@ -520,6 +520,30 @@ void SyRouting::writeRtpData(unsigned src_slot,const char *data,int len) const
 }
 
 
+QHostAddress SyRouting::streamAddress(SyRouting::Realm realm,uint16_t lw_num)
+{
+  //
+  // From page 113 of 'Intro to Livewire, v2.1.1'
+  //
+  QHostAddress ret;
+  switch(realm) {
+  case SyRouting::Stereo:    // 239.192.0.0/15
+    ret.setAddress(4022337536+lw_num);
+    break;
+
+  case SyRouting::Backfeed:  // 239.193.0.0/15
+    ret.setAddress(4022403072+lw_num);
+    break;
+
+  case SyRouting::Surround:  // 239.128.0.0/15
+    ret.setAddress(4022599680+lw_num);
+    break;
+  }
+
+  return ret;
+}
+
+
 unsigned SyRouting::livewireNumber(const QHostAddress &addr)
 {
   return 0xFFFF&addr.toIPv4Address();
